summaryrefslogtreecommitdiff
path: root/src/shared/dlt_user_shared.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/shared/dlt_user_shared.h')
-rwxr-xr-xsrc/shared/dlt_user_shared.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/src/shared/dlt_user_shared.h b/src/shared/dlt_user_shared.h
index a29a045..0fd6367 100755
--- a/src/shared/dlt_user_shared.h
+++ b/src/shared/dlt_user_shared.h
@@ -184,16 +184,15 @@ typedef struct
*/
typedef struct
{
- uint8_t log_mode; /**< the mode to be used for logging: off, external, internal, both */
+ int8_t log_mode; /**< the mode to be used for logging: off, external, internal, both */
} PACKED DltUserControlMsgLogMode;
/**
* This is the internal message content to get the logging state, broadcast to each application,
* when client connects or disconnects.
*/
typedef struct
{
- uint8_t log_state; /**< the mode to be used for logging: off, on */
+ int8_t log_state; /**< the state to be used for logging state: 0 = off, 1 = external client connected */
} PACKED DltUserControlMsgLogState;
/**************************************************************************************************
@@ -184,16 +184,15 @@ typedef struct
} PACKED DltUserControlMsgLogMode;
/**
- * This is the internal message content to get the logging state, broadcast to each application,
- * when client connects or disconnects.
+ * This is the internal message content to get the logging state: 0 = off, 1 = external client connected.
*/
typedef struct